@@ -4,11 +4,13 @@ from lazyops.utils.logs import default_logger as logger
 from lazyops.utils.lazylib import LazyLib
 from lazyops.utils.imports import (
     resolve_missing,
+    resolve_missing_custom,
     require_missing_wrapper,
 )
 from lazyops.utils.serialization import (
     object_serializer, object_deserializer,
     ObjectEncoder, ObjectDecoder,
+    Json,
 )
 from lazyops.utils.helpers import (
     timer,
