@@ -116,7 +116,7 @@ class InterceptHandler(logging.Handler):
         while frame.f_code.co_filename == logging.__file__:
             frame = frame.f_back
             depth += 1
-        log = logger.bind(request_id='app')
+        log = logger.bind(request_id=None)
         log.opt(
             depth=depth,
             exception=record.exc_info
@@ -160,11 +160,11 @@ class CustomizeLogger:
                 status = record['extra'].get('status')
                 color = STATUS_COLOR.get(status, FALLBACK_STATUS_COLOR)
                 kind_color = STATUS_COLOR.get(record.get('extra', {}).get('kind'), FALLBACK_STATUS_COLOR)
-                extra = '<light-blue>{extra[queue_name]}</>:<' + kind_color + '>{extra[kind]:<9}</><' + color + '>{extra[job_id]}</> '
+                extra = '<cyan>{extra[queue_name]}</>:<' + kind_color + '>{extra[kind]:<9}</><' + color + '>{extra[job_id]}</> '
 
             elif record['extra'].get('kind') and record['extra'].get('queue_name'):
                 kind_color = STATUS_COLOR.get(record.get('extra', {}).get('kind'), FALLBACK_STATUS_COLOR)
-                extra = '<light-blue>{extra[queue_name]}</>:<' + kind_color + '>{extra[kind]:<9}</> '
+                extra = '<cyan>{extra[queue_name]}</>:<' + kind_color + '>{extra[kind]:<9}</> '
 
         if 'result=tensor([' not in str(record['message']):
             return "<level>{level: <8}</> <green>{time:YYYY-MM-DD HH:mm:ss.SSS}</>: "\
